package secret

import (
	"time"
)

// VaultMetadata contains information about a vault
type VaultMetadata struct {
	CreatedAt       time.Time `json:"createdAt"`
	Description     string    `json:"description,omitempty"`
	DerivationIndex uint32    `json:"derivation_index"`
	// Double SHA256 hash of the actual long-term public key
	PublicKeyHash string `json:"public_key_hash,omitempty"`
	// Double SHA256 hash of index-0 key (for grouping vaults from same mnemonic)
	MnemonicFamilyHash string `json:"mnemonic_family_hash,omitempty"`
}

// UnlockerMetadata contains information about an unlocker
type UnlockerMetadata struct {
	Type      string    `json:"type"` // passphrase, pgp, keychain
	CreatedAt time.Time `json:"createdAt"`
	Flags     []string  `json:"flags,omitempty"`
}

// Metadata contains information about a secret
type Metadata struct {
	CreatedAt time.Time `json:"createdAt"`
	UpdatedAt time.Time `json:"updatedAt"`
}

// Configuration represents the global configuration
type Configuration struct {
	DefaultVault string `json:"defaultVault,omitempty"`
}
